@@ -57,23 +57,25 @@ def parse_gff(gff: str, type='gene'):
                            parse_gff_attributes(attr))
 
 
-def generate_bed(gff, type='gene'):
+def generate_bed(gff, type='gene', canon=False):
     for seqid, start, end, strand, attr in parse_gff(gff, type=type):
         gene_id = attr['ID'] if 'ID' in attr.keys() else attr['Parent'].split('_')[0]
-        yield seqid, start, end, gene_id, 0, strand
+        if attr['Parent'].endswith('_T001') or not canon:
+            yield seqid, start, end, gene_id, 0, strand
 
 
 def parse_arguments():
     parser = ArgumentParser(description='convert gff3 to bed12')
     parser.add_argument('gff', metavar='<input.gff3>', help='input gff3 file')
+    parser.add_argument('--canon', action='store_true', help='canonical transcripts only')
     return parser.parse_args()
 
 
 def main():
     args = parse_arguments()
-    genes = BedTool(tuple(generate_bed(args.gff))).sort()
-    exons = BedTool(tuple(generate_bed(args.gff, type='exon'))).sort()
-    cds = BedTool(tuple(generate_bed(args.gff, type='CDS'))).sort()
+    genes = BedTool(tuple(generate_bed(args.gff, canon=args.canon))).sort()
+    exons = BedTool(tuple(generate_bed(args.gff, type='exon', canon=args.canon))).sort()
+    cds = BedTool(tuple(generate_bed(args.gff, type='CDS', canon=args.canon))).sort()
     for gene in genes:
         block_size, block_start = zip(
             *((str(exon.stop - exon.start), str(exon.start - gene.start))
